#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::Repository;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Services::Repository;
use Vhffs::Panel::Main;
use Vhffs::Constants;

sub getall_repository_to_moderate
{
        my( $main , $query , $request);
        $main = shift;
        $query = "SELECT r.name , o.description ,  u.username , g.groupname , o.object_id FROM vhffs_repository r, vhffs_object o , vhffs_users u , vhffs_groups g  WHERE u.uid=r.owner_uid AND g.gid=r.owner_gid AND o.object_id=r.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
        $request = $main->{'db'}->{'DB_READ'}->prepare( $query );

        return undef if ( $request->execute <= 0 );
        return( $request->fetchall_hashref('name') );
}


sub getall_repository
{
        my $main = shift;
        my $name = shift;

        my $query;

	if( defined $name )
        {
                $query = "SELECT r.name, r.owner_gid, o.state  FROM vhffs_repository r, vhffs_object o WHERE o.object_id=r.object_id AND r.name LIKE '".$name."'";
        }
        else
        {
                $query = "SELECT r.name, r.owner_gid, o.state  FROM vhffs_repository r, vhffs_object o WHERE o.object_id=r.object_id";
        }
        my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

        return undef if ( $request->execute() <= 0);

        return( $request->fetchall_hashref('name') );
}



sub create_repository
{
	my( $main , $name , $user , $group ) = @_;

	return -1 if( $user->fetch < 0 );
	return -2 if( $group->fetch < 0 );

	my $repo = new Vhffs::Services::Repository( $main , $name , $user , $group );

	return undef if( ! defined $repo);
	$repo->set_user( $user );
	$repo->set_group( $group );

	return undef if( $repo->create < 0 );

	return undef if ( Vhffs::Acl::add_acl( $user , $repo , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
	return undef if( Vhffs::Acl::add_acl( $group , $repo , Vhffs::Constants::ACL_VIEW , $main ) < 0 );

	return $repo;
}

sub menu
{
	my ( $class , $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $group = $data->{'group'};
	my $cgi = $data->{'cgi'};
	my $templatesdir = $vhffs->get_config->get_templatedir;
	my $repo;
	my $template = new HTML::Template( filename => "$templatesdir/repository/menu.tmpl" );
	$template->param( TEXT_CREATE => gettext("Create") );
	$template->param( TEXT_REPOSITORY => gettext("Download repository") );

	my $repos = Vhffs::Services::Repository::getall_per_group( $vhffs , $group );
	my $output = "";
	my $subtemplate;


	foreach $repo ( @{$repos}  )
	{
	    if( $repo->get_status == Vhffs::Constants::ACTIVATED )
	    {
		$subtemplate = new HTML::Template( filename => "$templatesdir/repository/menu_sub.tmpl" );
		$subtemplate->param( NAME => $repo->get_name );
		$subtemplate->param( HISTORY => gettext("History"));
		$subtemplate->param( OID => $repo->get_oid );
		$subtemplate->param( URL_NAME => gettext("URL") );
		$subtemplate->param( URL_VALUE => $vhffs->get_config->get_repositoryurl . "/" . $repo->get_name );
		$output .= $subtemplate->output;
	    }
	    else
	    {
			$subtemplate = new HTML::Template( filename => "$templatesdir/repository/menu_sub_wait.tmpl" );
			$subtemplate->param( NAME => $repo->get_name );
			$subtemplate->param( REASON => gettext( Vhffs::Functions::status_string_from_status_id( $repo->get_status ) ) );
			$subtemplate->param( HISTORY => gettext("History"));
			$subtemplate->param( OID => $repo->get_oid );
			$output .= $subtemplate->output;
	    }
	}
	
	$template->param( SUB_REPOSITORY => $output );
	return $template->output;
}

1;
