#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



# This file is a part of VHFFS4
# It is used to manage Web Area in VHFFS hosting platform
# Please respect the licence of this file, and the whole VHFFS software.

# Author: soda < dieu at gunnm dot org>

package Vhffs::Services::Httpd;

use base qw(Vhffs::Object);
use strict;
use DBI;



sub new
{
    my $main;
    my $servername;
    my $this;
    my $self;
    my $class;
	my $user;
	my $group;

    ( $class , $main , $servername , $user , $group ) = @_;
				    
    $this = {};

	#return undef if( $user->fetch < 0);
    $this = $class->SUPER::new( $main , 1 , '401' );
   
   return undef if( ! ($servername =~ /^[a-z0-9](([a-z0-9]\-{0,1})+\.)+[a-z]{2,4}$/ ) );
   return undef if( $servername =~ /\.\./ );
	
	$this->{'servername'} = $servername if ( defined $servername );

   # $this->{'owner_uid'} = $user->{'uid'} if ( defined $user->{'uid'} );
   	$this->{'user'} = $user;
	$this->{'group'} = $group;

    bless( $this , $class );

	return $this;
}

sub delete
{
    my $self = shift;
    my $query = "DELETE FROM vhffs_httpd WHERE object_id='".$self->{'object_id'}."'";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;
	
	return -2 if( $self->SUPER::delete < 0 );

	return 1;
}


sub create
{
	my $self = shift;

	return -1 if( $self->{'user'}->fetch < 0 );
	return -1 if( $self->{'group'}->fetch < 0 );

	$self->{'owner_uid'} = $self->{'user'}->get_uid;
	$self->{'owner_gid'} = $self->{'group'}->get_gid;


	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_httpd WHERE servername='" . $self->{'servername'} . "'");
    my $rows = $request->execute;
    return -2 if ( $rows != 0 );

    my $oid = $self->SUPER::create();
    return -3 if ( $oid lt 0 );

	#Get the mac httpd_id and compute the new httpd_id
    my $httpd_id = 1;
    my $resultuid = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(httpd_id) FROM vhffs_httpd");
    $httpd_id = $resultuid->[0][0] if ( defined $resultuid->[0][0] );
    $httpd_id++;


	#Finally, create the object
	my $query = "INSERT INTO vhffs_httpd VALUES( '".$httpd_id."' , '".$self->{'servername'} . "', '1' , '".$self->{'owner_uid'}."' , '".$self->{'owner_uid'}."' , '".$self->{'owner_uid'}."' , '".$self->{'group'}->get_gid."', '0' , '0' , '0' , $oid  )";
	$request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute or return -2;

	return $httpd_id;
}


#Get all data about this httpd object in the databse
sub fetch
{
	my $self = shift;
	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_httpd where servername='".$self->{'servername'}."'") or return -1;

    my $rows = $request->execute() or return -3;

	return -1 if( $rows <= 0 );

    my $result = $request->fetchrow_hashref();


	foreach ( keys %{$result} )
	{
		$self->{$_} = $result->{$_}
	}

	$self->SUPER::fetch;

    $self->{'group'} = new Vhffs::Group( $self->{'main'} , undef ,  $self->{'owner_uid'} , $self->{'owner_gid'} );
    return -1 if( $self->{'group'}->fetch < 0 );

    $self->{'user'} = new  Vhffs::User( $self->{'main'} , undef , $self->{'owner_uid'} );
    return -1 if( $self->{'user'}->fetch < 0 );

	return 1;
}



sub commit
{
	my $self = shift;	

	$self->{'crawl'} = 0 if( ! defined $self->{'crawl'} );
	$self->{'trafic'} = 1 if( ! defined $self->{'trafic'} );

	my $query = "UPDATE vhffs_httpd SET crawl='".$self->{'crawl'}."', trafic= '".$self->{'trafic'}."' WHERE servername='".$self->{'servername'}."'";
	my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute;


	$self->SUPER::commit;
}


sub get_alertstate
{
	my $self = shift;
	return $self->{'alert_state'};
}



sub get_alertlimit
{
	my $self = shift;
	return $self->{'alert_limit'};
}

sub get_crawl
{
	my $self = shift;
	return $self->{'crawl'};
}

sub set_crawl
{
	my( $self , $value ) = @_;
		$self->{'crawl'} = $value;
}

sub get_servername
{
	my $self = shift;
	return $self->{'servername'};
}

sub get_title
{
	my $self = shift;
	return $self->{'servername'};
}

sub get_trafic
{
	my $self = shift;
	return $self->{'trafic'};
}


sub set_trafic
{
	my ($self , $value) = @_;	
	$self->{'trafic'} = $value;
}

sub set_alertlimit
{
	my ($self , $value) = @_;	
	$self->{'alert_limit'} = $value;
}

sub set_alertstate
{
	my ($self , $value) = @_;	
	$self->{'alert_state'} = $value;
}

sub set_user
{
	my( $self , $user ) = @_;
	$self->{'user'} = $user;
}



sub set_group
{
	my( $self , $group )  = @_;
	$self->{'group'} = $group;
}

sub get_owneruid
{
	my $self = shift;
	return $self->{'owner_uid'};
}

sub get_ownergid
{
	my $self = shift;
	return $self->{'owner_gid'};
}


sub getall
{
    my $vhffs = shift;
    my $state = shift;
    my $name = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

	$query = "SELECT w.servername, w.object_id FROM  vhffs_httpd w, vhffs_object o WHERE w.object_id = o.object_id";
    $query .= " AND o.state='".$state."'" if( defined $state );
    $query .= " AND w.servername LIKE '%".$name."%'" if( defined $name );
    $query .= " AND w.owner_gid='".$group->get_gid."'" if( defined $group );
    
	
	$query .= " ORDER BY servername";
    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows == 0);

    while( $result = $request->fetchrow_hashref )
    {
        $tmp = new Vhffs::Services::Httpd( $vhffs , $result->{'servername'} );
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}


sub search
{
    my $vhffs = shift;
    my $state = shift;
    my $name = shift;
    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

    if( ( defined $state ) && ( $state < Vhffs::Constants::TO_DELETE ) )
    {
        $query = "SELECT w.servername, w.object_id FROM  vhffs_httpd w, vhffs_object o WHERE o.state='".$state."' AND w.object_id = o.object_id AND ( o.description LIKE '%$name%' OR w.servername LIKE '%name%' )";
    }
    else
    {
        $query = "SELECT w.servername, w.object_id FROM  vhffs_httpd w, vhffs_object o WHERE w.object_id = o.object_id";
    }
    $query .= " ORDER BY servername";
    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows == 0);

#    $result = $request->fetchall_hashref( 'servername' );

    while( $result = $request->fetchrow_hashref )
    {
        $tmp = new Vhffs::Services::Httpd( $vhffs , $result->{'servername'} );
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}


sub getall_by_group
{
    my $vhffs = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

     
    $query = "SELECT w.servername, w.object_id FROM  vhffs_httpd w, vhffs_object o WHERE w.object_id = o.object_id AND w.owner_gid='".$group->get_gid."'";
    
    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows == 0);

    $result = $request->fetchall_hashref( 'servername' );

    foreach( keys %{$result} )
    {
        $tmp = new Vhffs::Services::Httpd( $vhffs , $_ );
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}




1;
