#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


#Vhffs::ACL written by sod` <dieu AT gunnm DOT org>

# This software is free software, please read LICENCE file
package Vhffs::Stats;

#General perl modules
use base qw(Vhffs::Object);
use strict;

#Vhffs specific modules
use Vhffs::Constants;


sub new
{
    my $this;
    my $self;

    my ( $class , $main ) = @_;
    
    $this = {};

    
    $this->{'main'} = $main;
    $this->{'db'} = $main->get_db_object;
    bless( $this , $class );
}


sub fetch
{
    my ( $self , $query , $request , $result );
    $self = shift;

    $query = "SELECT COUNT(*) FROM vhffs_users";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'users'}{'total'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_users WHERE admin='".Vhffs::Constants::USER_ADMIN."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'users'}{'total_admin'} = $result->[0][0] if ( defined $result->[0][0] );


    $query = "SELECT COUNT(*) FROM vhffs_users WHERE admin='".Vhffs::Constants::USER_MODERATOR."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'users'}{'total_moderator'} = $result->[0][0] if ( defined $result->[0][0] );


    $query = "SELECT COUNT(*) FROM vhffs_groups g WHERE g.groupname NOT IN ( SELECT username FROM vhffs_users )";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'groups'}{'total'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_groups g, vhffs_object o WHERE o.object_id=g.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."' AND g.groupname NOT IN (SELECT username FROM vhffs_users)";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'groups'}{'waited_moderation'} = $result->[0][0] if ( defined $result->[0][0] );


    $query = "SELECT COUNT(*) FROM vhffs_groups g, vhffs_object o WHERE o.object_id=g.object_id AND o.state='".Vhffs::Constants::ACTIVATED."' AND g.groupname NOT IN (SELECT username FROM vhffs_users)";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'groups'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );


    $query = "SELECT COUNT(*) FROM vhffs_httpd w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'web'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_httpd w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'web'}{'waited'} = $result->[0][0] if ( defined $result->[0][0] );
    $self->{'web'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_httpd w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'web'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );


    $query = "SELECT COUNT(*) FROM vhffs_cvs w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'cvs'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_cvs w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'cvs'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_cvs w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'cvs'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );


    ### DNS Stats
    $query = "SELECT COUNT(*) FROM vhffs_dns_global w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'dns'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_dns_global w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'dns'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_dns_global w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'dns'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );


    ###Stats for mail
    $query = "SELECT COUNT(*) FROM vhffs_mxdomain w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mail'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_mxdomain w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mail'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_mxdomain w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mail'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_boxes";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mail'}{'total_boxes'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_forward";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mail'}{'total_forwards'} = $result->[0][0] if ( defined $result->[0][0] );


    ### Stats for MySQL 
    $query = "SELECT COUNT(*) FROM vhffs_mysql w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mysql'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_mxdomain w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mysql'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_mxdomain w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'mysql'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );


    ### Stats for Pgsql
    $query = "SELECT COUNT(*) FROM vhffs_pgsql w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'pgsql'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_pgsql w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'pgsql'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_pgsql w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'pgsql'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_svn w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'svn'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_svn w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'svn'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_svn w, vhffs_object o WHERE o.object_id=w.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'svn'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_ml ml, vhffs_object o WHERE o.object_id=ml.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'lists'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_ml ml, vhffs_object o WHERE o.object_id=ml.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'lists'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_ml ml, vhffs_object o WHERE o.object_id=ml.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'lists'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_ml";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'lists'}{'total'} = $result->[0][0] if ( defined $result->[0][0] );

    $query = "SELECT COUNT(*) FROM vhffs_ml_subscribers";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'lists'}{'totalsubs'} = $result->[0][0] if ( defined $result->[0][0] );
   

    $query = "SELECT COUNT(*) FROM vhffs_largefile lf, vhffs_object o WHERE o.object_id=lf.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'largefile'}{'activated'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_largefile lf , vhffs_object o WHERE o.object_id=ls.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'largefile'}{'waited_validation'} = $result->[0][0] if ( defined $result->[0][0] );
    
    $query = "SELECT COUNT(*) FROM vhffs_largefile lf , vhffs_object o WHERE o.object_id=lf.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_CREATION."'";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'largefile'}{'waited_creation'} = $result->[0][0] if ( defined $result->[0][0] );


    $query = "SELECT COUNT(*) FROM vhffs_largefile lf , vhffs_object o WHERE o.object_id=lf.object_id";
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref( $query );
    $self->{'largefile'}{'total'} = $result->[0][0] if ( defined $result->[0][0] );

    return 1;
}

sub get_lists_totalsubs
{
    my $self = shift;
    return $self->{'lists'}{'totalsubs'};
}



sub get_lists_in_moderation
{
    my $self = shift;
    return $self->{'lists'}{'waited_validation'};
}

sub get_lists_activated
{
    my $self = shift;
    return $self->{'lists'}{'activated'};
}

sub get_lists_total
{
    my $self = shift;
    return $self->{'lists'}{'total'};
}



sub get_web_in_moderation
{
    my $self = shift;
    return $self->{'web'}{'waited'};
}

sub get_web_activated
{
    my $self = shift;
    return $self->{'web'}{'activated'};
}


sub get_user_total
{
    my $self = shift;
    return $self->{'users'}{'total'};
}


sub get_user_total_admin
{
    my $self = shift;
    return $self->{'users'}{'total_admin'};
}


sub get_user_total_moderator
{
    my $self = shift;
    return $self->{'users'}{'total_moderator'};
}



sub get_dns_in_moderation
{
    my $self = shift;
    return $self->{'dns'}{'waited_validation'};
}

sub get_dns_activated
{
    my $self = shift;
    return $self->{'dns'}{'activated'};
}


sub get_mail_in_moderation
{
    my $self = shift;
    return $self->{'mail'}{'waited_validation'};
}

sub get_mail_activated
{
    my $self = shift;
    return $self->{'mail'}{'activated'};
}

sub get_mail_total_boxes
{
    my $self = shift;
    return $self->{'mail'}{'total_boxes'};
}

sub get_mail_total_forwards
{
    my $self = shift;
    return $self->{'mail'}{'total_forwards'};
}


sub get_cvs_in_moderation
{
    my $self = shift;
    return $self->{'cvs'}{'waited_validation'};
}

sub get_cvs_activated
{
    my $self = shift;
    return $self->{'cvs'}{'activated'};
}


sub get_svn_in_moderation
{
    my $self = shift;
    return $self->{'svn'}{'waited_validation'};
}


sub get_largefile_in_moderation
{
    my $self = shift;
    return $self->{'largefile'}{'waited_validation'};
}

sub get_largefile_total
{
    my $self = shift;
    return $self->{'largefile'}{'total'};
}

sub get_svn_activated
{
    my $self = shift;
    return $self->{'svn'}{'activated'};
}

sub get_largefile_activated
{
    my $self = shift;
    return $self->{'largefile'}{'activated'};
}


sub get_mysql_in_moderation
{
    my $self = shift;
    return $self->{'mysql'}{'waited_validation'};
}

sub get_mysql_activated
{
    my $self = shift;
    return $self->{'mysql'}{'activated'};
}


sub get_pgsql_in_moderation
{
    my $self = shift;
    return $self->{'pgsql'}{'waited_validation'};
}

sub get_pgsql_activated
{
    my $self = shift;
    return $self->{'pgsql'}{'activated'};
}

sub get_groups_in_moderation
{
    my $self = shift;
    return $self->{'groups'}{'waited_moderation'};
}


sub get_groups_activated
{
    my $self = shift;
    return $self->{'groups'}{'activated'};
}

sub get_groups_total
{
    my $self = shift;
    return $self->{'groups'}{'total'};
}


1;
