#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $cgigroupname = $cgi->param('cgigroup');
my $repo_name = $cgi->param("name");
my $template;
my $output;
my $subtemplate;
my $svn;
my $templatedir;
my $message;

$templatedir = $vhffs->get_config->get_templatedir;

if( defined $cgigroupname )
{
	$group = new Vhffs::Group( $vhffs , $cgigroupname , '401' );
	$group->fetch;
}

$svn = new Vhffs::Services::Svn( $vhffs , $repo_name  , undef , $group );


if( ( ! defined $repo_name ) || ( ! defined $svn ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "CGI Error" );
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined $group ) || ( $group->fetch < 0 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$template->param( MESSAGE => gettext("Grant an user access to this repository") );
}
elsif( $svn->fetch < 0 )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $svn , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
elsif( ( $svn->get_status != Vhffs::Constants::ACTIVATED ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
    $message = gettext( "This object is not functionnal yet. Please wait creation, moderation or modification.");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/svn/prefs.tmpl" );

	$template->param( TEXT_TITLE => gettext("Admin Subversion Repository") );
	
	
	$template->param( TEXT_REPONAME => $svn->get_reponame );
	$template->param( TITLE_PUBLIC => gettext("Public") );
	$template->param( TEXT_PUBLIC => gettext("Is this a public repository ?") );
	$template->param( PUBLIC_YES => gettext("Yes") );
	$template->param( PUBLIC_NO => gettext("No") );
	$template->param( TEXT_SEND => gettext("Modify") );
	$template->param( TEXT_DELETE_CVS => gettext("Delete this repository") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. All services associated to this project will be DESTROYED.") );
	$template->param( ASK_DELETE_CVS => gettext("Are you SURE you want DELETE this  subversion repository ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

    $template->param( TEXT_ACL_ADMIN => "Admin Rights on this object (ACL)" );
    $template->param( EXPLAIN_ADMIN_ACL => "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it." );
    $template->param( ADMIN_ACL => "Ok, go to ACL admin" );
    $template->param( TITLE_PERM => "Fix permissions in this repository" );
    $template->param( PERM_TEXT => "Fixing permissions on a repository solve permission access on the repository. Can be helpful if you encounter problems" );
    $template->param( TEXT_BUTTON_PERM => "Fix them !" );


	
	
	if( $svn->is_public == 1 )
	{
    	$template->param( YES_SELECTED => "selected" );
	}
	else
	{
    	$template->param( NO_SELECTED => "selected" );
	}

	if( $user->is_admin == 1 )
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/admin/misc/opart.tmpl" );
		$subtemplate->param( OID => $svn->get_oid );
		$subtemplate->param( OPART_TEXT => gettext("Go to object-part admin") );
		$subtemplate->param( OPART_TITLE => gettext("Object part") );
		$template->param( OPART => $subtemplate->output );
	}


}

display Vhffs::Panel::Main($panel, $template->output );
