#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;

use Vhffs::Main;
use Vhffs::Constants;
use Vhffs::Services::Cvs;
use Vhffs::Services::Svn;
use HTML::Template;

my $sampleconf = "/usr/lib/vhffs/bots/misc/viewvc.conf.tmpl";

my $vhffs = init Vhffs::Main;

my $confdir = $vhffs->get_config->get_datadir . "/conf/";
mkdir( $confdir ) if( ! -d $confdir );

my $ouputfile = $confdir . "viewvc.conf";

my $cvsroots;
my $svnroots;

if( $vhffs->get_config->use_cvs == 1 )
{
	my $cvss = Vhffs::Services::Cvs::getall( $vhffs , Vhffs::Constants::ACTIVATED );
	my $cvs;

	foreach $cvs ( @{$cvss} )
	{
		if( $cvs->is_public == 1 )
		{
			$cvsroots .= "  cvs_" . $cvs->get_group->get_groupname . "_" . $cvs->get_cvsroot . ": " . $cvs->get_dir . ",\n";
		}
	}
}

if( $vhffs->get_config->use_svn == 1 )
{
	my $svns = Vhffs::Services::Svn::getall( $vhffs , Vhffs::Constants::ACTIVATED );
	my $svn;

	foreach $svn ( @{$svns} )
	{
		if( $svn->is_public == 1 )
		{
			$svnroots .= "  svn_" . $svn->get_group->get_groupname . "_" . $svn->get_reponame . ": " . $svn->get_dir . ",\n";
		}
	}
}

my $template = new HTML::Template( filename => "$sampleconf" );
$template->param( CVSROOTS => "cvs_roots = ".$cvsroots ) if ( defined $cvsroots );
$template->param( SVNROOTS => "svn_roots = ".$svnroots ) if ( defined $svnroots );

open( OUTPUT , ">$ouputfile" );
print OUTPUT $template->output;
close( OUTPUT );
